@@ -44,9 +44,10 @@ General utility functions
 #
 
 # stdlib
+import inspect
 import itertools
 import sys
-from typing import Any, Generator, Iterable, List, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, Generator, Iterable, List, Optional, Sequence, Tuple, Union
 
 __all__ = [
 		"pyversion",
@@ -66,6 +67,9 @@ __all__ = [
 		"str2tuple",
 		"strtobool",
 		"enquote_value",
+		"Len",
+		"double_chain",
+		"posargs2kwargs",
 		]
 
 pyversion: int = int(sys.version_info.major)  # Python Version
@@ -136,7 +140,7 @@ def cmp(x, y) -> int:
 
 	Compare the two objects x and y and return an integer according to the outcome.
 
-	The return value is negative if x < y, zero if x == y and strictly positive if x > y.
+	The return value is negative if ``x < y``, zero if ``x == y`` and strictly positive if ``x > y``.
 	"""
 
 	return int((x > y) - (x < y))
@@ -195,7 +199,7 @@ def printt(obj: Any, *args, **kwargs) -> None:
 	print(type(obj), *args, **kwargs)
 
 
-def stderr_writer(*args, **kwargs):
+def stderr_writer(*args, **kwargs) -> None:
 	"""
 	Write to stderr, flushing stdout beforehand and stderr afterwards.
 	"""
@@ -235,7 +239,7 @@ def str2tuple(input_string: str, sep: str = ',') -> Tuple[int, ...]:
 
 		The input string must represent a comma-separated series of integers.
 
-	TODO: Allow custom types, not just ``int`` (making ``int`` the default)
+	.. TODO:: Allow custom types, not just ``int`` (making ``int`` the default)
 
 	:param input_string: The string to be converted into a tuple
 	:type input_string: str
@@ -273,9 +277,10 @@ def strtobool(val: Union[str, bool]) -> bool:
 
 def enquote_value(value: Any) -> Union[str, bool, float]:
 	"""
-	Adds quotes to the given value, suitable for use in a templating system such as Jinja2.
+	Adds quotes (``'``) to the given value, suitable for use in a templating system such as Jinja2.
 
-	floats, integers, booleans, None, and the strings "True", "False" and "None" are returned as-is.
+	:class:`Floats <float>`, :class:`integers <int>`, :class:`booleans <bool>`, :py:obj:`None`,
+	and the strings ``'True'``, ``'False'`` and ``'None'`` are returned as-is.
 
 	:param value: The value to enquote
 	"""
@@ -337,3 +342,33 @@ def double_chain(iterable: Iterable[Iterable]):
 	"""
 
 	yield from itertools.chain.from_iterable(itertools.chain.from_iterable(iterable))
+
+
+def posargs2kwargs(
+		args: Iterable[Any],
+		posarg_names: Union[Iterable[str], Callable],
+		kwargs: Optional[Dict[str, Any]] = None,
+		) -> Dict[str, Any]:
+	"""
+	Convert the positional args in ``args`` to kwargs, based on the relative order of ``args`` and ``posarg_names``.
+
+	:param args: List of positional arguments provided to a function.
+	:param posarg_names: Either a list of positional argument names for the function, or the function object.
+	:param kwargs: Optional mapping of keyword argument names to values.
+		The arguments will be added to this dictionary if provided.
+	:default kwargs: ``{}``
+
+	:return: Dictionary mapping argument names to values.
+
+	.. versionadded:: 0.4.10
+	"""
+
+	if kwargs is None:
+		kwargs = {}
+
+	if callable(posarg_names):
+		posarg_names = inspect.getfullargspec(posarg_names).args
+
+	kwargs.update(zip(posarg_names, args))
+
+	return kwargs
